Format
A data frame with 1684 observations on the following 10 variables.
- id
- Unique identification numbers for each fish
- y1998
- Indicator variable for whether the fish was captured in 1998 (
1=captured) - y1999
- Indicator variable for whether the fish was captured in 1999 (
1=captured) - y2000
- Indicator variable for whether the fish was captured in 2000 (
1=captured) - y2001
- Indicator variable for whether the fish was captured in 2001 (
1=captured) - y2002
- Indicator variable for whether the fish was captured in 2002 (
1=captured) - y2003
- Indicator variable for whether the fish was captured in 2003 (
1=captured) - y2004
- Indicator variable for whether the fish was captured in 2004 (
1=captured) - y2005
- Indicator variable for whether the fish was captured in 2005 (
1=captured) - y2006
- Indicator variable for whether the fish was captured in 2006 (
1=captured)
From Appendix A.3 of Harding, R.D., C.L. Hoover, and R.P. Marshall. 2010. Abundance of Cutthroat Trout in Auke Lake, Southeast Alaska, in 2005 and 2006. Alaska Department of Fish and Game Fisheries Data Series No. 10-82. [Was (is?) from http://www.sf.adfg.state.ak.us/FedAidPDFs/FDS10-82.pdf.]Topic(s)
- Population Size
- Abundance
- Mark-Recapture
- Capture-Recapture
- Jolly-Seber
- Capture History