Learn R Programming

FSA (version 0.8.8)

PikeNY: Summarized multiple mark-recapture data for all Northern Pike from Buckthorn Marsh, NY.

Description

Summary results of capture histories (number captured, number of recaptured fish, and number of unmarked fish that were marked) for all Buckthorn Marsh Northern Pike (Esox lucius).

Arguments

Format

A data frame with 21 observations on the following 4 variables:
date
Capture date
n
Total fish captured in each sample
m
Marked fish captured in each sample
R
Marked fish returned to the population

New York Power Authority. 2004. Use of buckhorn marsh and grand island tributaries by northern pike for spawning and as a nursery. Technical report, New York Power Authority, January 2004. Niagara Power Project (FERC No. 2216).

Topic(s)

  • Population Size
  • Abundance
  • Mark-Recapture
  • Capture-Recapture
  • Schnabel
  • Schumacher-Eschmeyer

Examples

Run this code
data(PikeNY)
str(PikeNY)
head(PikeNY)

Run the code above in your browser using DataLab